@@ -22,25 +22,28 @@ def _format_command_output(output: str) -> str:
 
 
 class SourcePackage:
-    def __init__(self, blueprint: Blueprint, work_directory: Path):
+    def __init__(self, blueprint: Blueprint, output_directory: Path):
         self.directory_name = f"{blueprint.name}_{blueprint.version}_{blueprint.arch}"
-        self.output_directory = (work_directory / self.directory_name).absolute()
-        self.debian_directory = self.output_directory / "debian"
-        self.src_directory = self.output_directory / "src"
-        self.tmp_directory = Path(f"/tmp/ops2deb_{self.directory_name}")
+        self.package_directory = (output_directory / self.directory_name).absolute()
+        self.debian_directory = self.package_directory / "debian"
+        self.src_directory = self.package_directory / "src"
+        self.fetch_directory = Path(f"/tmp/ops2deb_{self.directory_name}")
         self.blueprint = blueprint.render(self.src_directory)
+        self.debian_version = (
+            f"{self.blueprint.version}-{self.blueprint.revision}~ops2deb"
+        )
 
     def render_tpl(self, template_name: str) -> None:
         template = _environment.get_template(f"{template_name}.j2")
         package = self.blueprint.dict(exclude={"fetch", "script"})
-        package.update({"version": self.blueprint.debian_version})
+        package.update({"version": self.debian_version})
         template.stream(package=package).dump(str(self.debian_directory / template_name))
 
     def init(self) -> None:
         shutil.rmtree(self.debian_directory, ignore_errors=True)
         self.debian_directory.mkdir(parents=True)
-        shutil.rmtree(self.tmp_directory, ignore_errors=True)
-        self.tmp_directory.mkdir()
+        shutil.rmtree(self.fetch_directory, ignore_errors=True)
+        self.fetch_directory.mkdir()
         shutil.rmtree(self.src_directory, ignore_errors=True)
         self.src_directory.mkdir(parents=True)
         for path in ["usr/bin", "usr/share", "usr/lib"]:
@@ -51,19 +54,21 @@ class SourcePackage:
             await fetch(
                 url=remote_file.url,
                 expected_hash=remote_file.sha256,
-                save_path=self.tmp_directory,
+                save_path=self.fetch_directory,
             )
         return self
 
     def generate(self) -> None:
         logger.title(f"Generating source package {self.directory_name}...")
 
+        # if blueprint has no fetch instruction, we stay in the directory from which
+        # ops2deb was called
+        cwd = self.fetch_directory if self.blueprint.fetch else Path(".")
+
         # run script
         for line in self.blueprint.script:
             logger.info(f"$ {line}")
-            result = subprocess.run(
-                line, shell=True, cwd=self.tmp_directory, capture_output=True
-            )
+            result = subprocess.run(line, shell=True, cwd=cwd, capture_output=True)
             if stdout := result.stdout.decode():
                 logger.info(_format_command_output(stdout))
             if stderr := result.stderr.decode():
@@ -83,33 +88,33 @@ class SourcePackage:
             self.render_tpl(template)
 
 
-def filter_already_published_blueprints(
-    blueprints: List[Blueprint], debian_repository: str
-) -> List[Blueprint]:
+def filter_already_published_packages(
+    packages: List[SourcePackage], debian_repository: str
+) -> List[SourcePackage]:
     already_published_packages = sync_list_repository_packages(debian_repository)
-    filtered_blueprints: List[Blueprint] = []
-    for blueprint in blueprints:
+    filtered_packages: List[SourcePackage] = []
+    for package in packages:
         if (
             DebianRepositoryPackage(
-                blueprint.name, blueprint.debian_version, blueprint.arch
+                package.blueprint.name, package.debian_version, package.blueprint.arch
             )
             not in already_published_packages
         ):
-            filtered_blueprints.append(blueprint)
-    return filtered_blueprints
+            filtered_packages.append(package)
+    return filtered_packages
 
 
 def generate(
     blueprints: List[Blueprint],
-    work_directory: Path,
+    output_directory: Path,
     debian_repository: Optional[str] = None,
 ) -> None:
 
+    packages = [SourcePackage(blueprint, output_directory) for blueprint in blueprints]
+
     # filter out blueprints that build packages already available in the debian repository
     if debian_repository is not None:
-        blueprints = filter_already_published_blueprints(blueprints, debian_repository)
-
-    packages = [SourcePackage(b, work_directory) for b in blueprints]
+        packages = filter_already_published_packages(packages, debian_repository)
 
     # make sure we generate source packages in a clean environment
     # without artifacts from previous builds
